@@ -254,6 +254,17 @@ def _show_status(res, light=True):
                 print(f'  {k}={v}')
 
 
+def killtree(pid, killme=True, signal=9):
+    """Kill a process tree"""
+    myself = psutil.Process(int(pid))
+    children = myself.children(recursive=True)
+    if killme:
+        children.append(myself)
+    for proc in children:
+        proc.send_signal(signal)
+
+    return bool(psutil.wait_procs(children))
+
 def main():
     config = _read_config()
     pm3_home_dir = config['main_section'].get('pm3_home_dir')
@@ -368,8 +379,8 @@ def main():
                                   pm3_id=0,
                                   shell=False,
                                   nohup=True,
-                                  stdout=f'{pm3_home_dir}/{backend_process_name}.log',
-                                  stderr=f'{pm3_home_dir}/{backend_process_name}.err')
+                                  stdout=f'{pm3_home_dir}/log/{backend_process_name}.log',
+                                  stderr=f'{pm3_home_dir}/log/{backend_process_name}.err')
                 p = backend.run()
                 time.sleep(2)
                 if psutil.Process(p.pid).is_running():
@@ -384,8 +395,16 @@ def main():
 
         if args.what == 'stop':
             if not res.err:
-                os.kill(msg['pid'], signal.SIGKILL)
-                print(f"send kill sig to pid {msg['pid']}")
+                #os.kill(msg['pid'], signal.SIGKILL)
+                #TODO: BUG quando lo start viene fatto da cli, lo stop fallisce perche' non prende il pid padre ma un
+                # figlio. Per rimediare:
+                # pid_to_kill = http_get(pid of backend) or msg['pid']
+                pid_to_kill = int(msg['pid'])
+                print(f"send kill sig to pid {pid_to_kill}")
+                if killtree(pid_to_kill):
+                    print(f"[green]process with pid {pid_to_kill} killed[/green]")
+                else:
+                    print(f"[red]can't stop process with pid: {pid_to_kill}[/red]")
             else:
                 print('process already stopped')
                 #print(res)
